@@ -125,12 +125,19 @@ class Channel:
                     retrying = i != 2
                     _dl_error("metadata", exception, retrying)
 
+                    # Try alternative route
+                    alt = "youtube.com/c/" in url
+                    if alt:
+                        url = "https://www.youtube.com/user/" + self.id
+
                     # Print retrying message
                     if retrying:
                         print(
                             Style.DIM
-                            + f"  • Retrying metadata download.."
-                            + Style.RESET_ALL
+                            + f"  • Retrying metadata download"
+                            + " with alternative route"
+                            if alt
+                            else "" + ".." + Style.RESET_ALL
                         )
 
         # # NOTE: remove for production
@@ -696,6 +703,7 @@ def _dl_error(name: str, exception: DownloadError, retrying: bool):
         "500",
         "Got error: The read operation timed out",
         "No such file or directory",
+        "HTTP Error 404: Not Found",
     ]
 
     # Download errors
@@ -716,6 +724,10 @@ def _dl_error(name: str, exception: DownloadError, retrying: bool):
         elif ERRORS[3] in exception.msg:
             msg = "Video deleted whilst downloading"
 
+        # Channel not found, will retry if its a "c/" vs "user/" failure
+        elif ERRORS[4] in exception.msg:
+            msg = "Couldn't find youtube channel by it's id"
+
     # Print error
     suffix = ", retrying in a few seconds.." if retrying else ""
     print(
@@ -736,6 +748,15 @@ def _dl_error(name: str, exception: DownloadError, retrying: bool):
         sys.exit(1)
 
 
+def _archive_not_found():
+    """Errors out the user if the archive doesn't exist"""
+    print(
+        "Archive doesn't exist, please make sure you typed it's name correctly!",
+        file=sys.stderr,
+    )
+    sys.exit(1)
+
+
 #
 # VIEWER
 #
@@ -905,29 +926,42 @@ def main():
             raise Exception("Please provide the archive name")
 
         # Refresh channel
-        channel = Channel.load(args[1])
-        channel.metadata()
-        channel.download()
-        channel.reporter.print()
+        try:
+            channel = Channel.load(args[1])
+            channel.metadata()
+            channel.download()
+            channel.reporter.print()
+        except ArchiveNotFoundException:
+            _archive_not_found()
 
     # View
     elif args[0] == "view":
-        # Get and start app
-        app = viewer()
-        threading.Thread(
-            target=lambda: app.run(host="127.0.0.1", port=7667, debug=False)
-        ).start()
+
+        def launch():
+            """Launches viewer"""
+            app = viewer()
+            threading.Thread(
+                target=lambda: app.run(host="127.0.0.1", port=7667, debug=False)
+            ).start()
 
         # Start on channel name
         if len(args) > 1:
             # Get name
             channel = args[1]
+
+            # Jank archive check
+            if not Path(channel).exists():
+                _archive_not_found()
+
+            # Launch and start browser
             print(f"Starting viewer for {channel}..")
+            launch()
             webbrowser.open(f"http://127.0.0.1:7667/channel/{channel}")
 
         # Start on channel finder
         else:
             print("Starting viewer..")
+            launch()
             webbrowser.open(f"http://127.0.0.1:7667/")
 
     # Unknown
